@@ -1,5 +1,5 @@
 /*
-   $Id: Pg.h 10832 2008-02-26 13:43:52Z turnstep $
+   $Id: Pg.h 10925 2008-03-16 13:34:23Z turnstep $
 
    Copyright (c) 2000-2008 Greg Sabino Mullane and others: see the Changes file
    Copyright (c) 1997-2000 Edmund Mergl
@@ -74,14 +74,12 @@ DBISTATE_DECLARE;
 #define FLAGS_END      0x04000000
 #define FLAGS_PREFIX   0x08000000
 #define FLAGS_LOGIN    0x10000000
-#define FLAGS_QUOTE    0x20000000
 
 #define TFLIBPQ      (TFLAGS & FLAGS_LIBPQ)
 #define TFSTART      (TFLAGS & FLAGS_START)
 #define TFEND        (TFLAGS & FLAGS_END)
 #define TFPREFIX     (TFLAGS & FLAGS_PREFIX)
 #define TFLOGIN      (TFLAGS & FLAGS_LOGIN)
-#define TFQUOTE      (TFLAGS & FLAGS_QUOTE)
 
 #define TRACE1       (TLEVEL >= 1) /* Avoid using directly: DBI only */
 #define TRACE2       (TLEVEL >= 2) /* Avoid using directly: DBI only */
@@ -96,7 +94,6 @@ DBISTATE_DECLARE;
 #define TSTART       (TRACE4 || TFSTART) /* Start of a major function */
 #define TEND         (TRACE4 || TFEND)   /* End of a major function   */
 #define TLOGIN       (TRACE5 || TFLOGIN) /* Connect and disconnect    */
-#define TSTARTQ      (TRACE6 || TFQUOTE) /* Quote functions           */
 
 #define TRACEWARN    (TRACE1) /* Non-fatal but serious problems */
 
@@ -156,7 +153,7 @@ DBISTATE_DECLARE;
 #define TRACE_PQSENDQUERYPREPARED  TRACE_XX "%sPQsendQueryPrepared\n",   THEADER)
 #define TRACE_PQSERVERVERSION      TRACE_XX "%sPQserverVersion\n",       THEADER)
 #define TRACE_PQSETERRORVERBOSITY  TRACE_XX "%sPQsetErrorVerbosity\n",   THEADER)
-#define TRACE_PQSETNOTICEPROCESSOR TRACE_XX "%sPQdsetNoticeProcessor\n", THEADER)
+#define TRACE_PQSETNOTICEPROCESSOR TRACE_XX "%sPQsetNoticeProcessor\n",  THEADER)
 #define TRACE_PQSOCKET             TRACE_XX "%sPQsocket\n",              THEADER)
 #define TRACE_PQSTATUS             TRACE_XX "%sPQstatus\n",              THEADER)
 #define TRACE_PQTRACE              TRACE_XX "%sPQtrace\n",               THEADER)
